@@ -35,7 +35,7 @@ def i_create_an_ensemble(step, number_of_models, tlp):
         number_of_models = int(number_of_models)
         tlp = int(tlp)
         args = {'number_of_models': number_of_models,
-                'tlp': tlp, 'sample_rate': 0.99}
+                'tlp': tlp, 'sample_rate': 0.99, 'seed': 'BigML'}
     except:
         args = {}
 
